@@ -3,6 +3,7 @@ Load/dump geometries using the well-known binary (WKB) format.
 """
 
 from ctypes import byref, c_int, c_size_t, c_char_p, string_at
+from ctypes import c_void_p, c_size_t
 
 from shapely.geos import lgeos, free, ReadingError
 from shapely.geometry.base import geom_factory
@@ -26,13 +27,14 @@ def load(fp):
 def dumps(ob):
     """Dump a WKB representation of a geometry to a byte string."""
     func = lgeos.GEOSGeomToWKB_buf
-    size = c_int()
+    size = c_size_t()
     def errcheck(result, func, argtuple):
+        if not result: return None
         retval = string_at(result, size.value)[:]
         free(result)
         return retval
     func.errcheck = errcheck
-    return func(ob._geom, byref(size))
+    return func(c_void_p(ob._geom), byref(size))
 
 def dump(ob, fp):
     """Dump a geometry to an open file."""
